@@ -58,6 +58,7 @@ class Database(object):
         'id': (lambda: random.randint(1, 6)),
         'codi': (lambda: random.choice(["TT101", "TT102", "TT103", "Q78544", "Q03566", "Q03585", "N19627", "N19640", "N19685", "N18427", "N18440", "N18485", "G76211", "G40291", "013731", "G40111", "Q85544", "Q75958", "W29485", "Q85585", "N18542", "N18527", "N18540", "N18585", "009780", "013110"])),
         'descripcio': (lambda: "lorem ipsum algo no se que cosas latin"),
+        'des': (lambda: "lorem ipsum otro algo no se latin"),
         'cataleg': (lambda: random.randint(1, 32)),
         'scs_codi': (lambda: "00089"),
         'ics_desc': (lambda: "ABS AMPOSTA"),
@@ -93,12 +94,13 @@ class Database(object):
                         data['val'] = info[1]()
                     else:
                         data[select] = Database.TEMPLATE[select]()
-                else:
-                    data[select] = random.randint(-50, -10)
-
-        sorted_data = sorted(data.items(), key=lambda x: sqlSelect.index(x[0]))
+                elif select != 'val':
+                    data[select] = str(random.randint(-50, -10))
+        sorted_data = sorted(data.items(), key=lambda x: sqlSelect.index(x[0])
+                             if x[0] in sqlSelect else
+                             len(sqlSelect) + 1)
         result = tuple(map(lambda d: d[1], sorted_data))
-        return result
+        return result[0:len(sqlSelect)]
 
     def connect(self, existent=True):
         """Desencripta password i connecta a la base de dades."""
